@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 
 # Author: Jason Mobarak
-# $Header: /var/cvsroot/gentoo-src/java-config/python/java_config/jc_options.py,v 1.34 2004/07/04 23:31:43 aether Exp $
+# $Header: /var/cvsroot/gentoo-src/java-config/python/java_config/jc_options.py,v 1.46 2006/09/06 23:35:52 nichoj Exp $
 
-__version__ = "$Revision: 1.34 $" [11:-2]
+__version__ = "$Revision: 1.46 $" [11:-2]
 
 import os
 import re
@@ -22,6 +22,7 @@ from jc_util import get_java_home
 from jc_util import get_jvm_env_var
 from jc_util import norm_cp
 from jc_util import collect_packages
+from jc_util import collect_library
 from jc_util import collect_vms
 from jc_util import die_no_jh
 from jc_util import warn
@@ -37,9 +38,6 @@ from jc_envgen import StdOutTcshEnvEntry
 from jc_output import *
 
 env = os.environ
-ENV_DIR = '/etc/env.d'
-USER_ENV_DIR = os.path.join(env['HOME'], '.gentoo')
-VM_DIR = os.path.join(ENV_DIR, 'java')
 JAVA_HOME = get_java_home()
 
 # I'm assuming it's safe to assume that keys like 'HOME' are 
@@ -85,6 +83,12 @@ def collect():
 
 	return options, option_to_class
 
+
+def report_env_update():
+
+	print "Env files in %s/.gentoo updated. Source these in your shell's profile." % (env['HOME'])
+			
+
 class Help (jc_iface.OptInterface):
 	
 	usage = (
@@ -98,8 +102,8 @@ class Help (jc_iface.OptInterface):
 
 	# Order that options are printed
 	order = [ 
-	  'J', 'c', 'j', 'O', 'o','f', 'v', 'p:', 'e:', 'l', 'L', 'P:', 
-	  'S:', 's:', 'A:', 'a:', 'B:', 'b:', 'X', 'x', 'n',
+	  'J', 'c', 'j', 'O', 'o','f', 'v', 'p:', 'g:', 'e:', 'l', 'L', 'P:', 
+	  'S:', 's:', 'A:', 'a:', 'B:', 'b:', 'X', 'x', 'n','i:',
 	]
 	
 	def _justify(self, S):
@@ -199,7 +203,7 @@ class Java (jc_iface.OptInterface):
 	names= ('J', 'java')
 
 	def __call__(self, args):
-		print find_exec('java')
+		print find_exec('java', JAVA_HOME)
 
 class Javac (jc_iface.OptInterface): 
 
@@ -214,7 +218,7 @@ class Javac (jc_iface.OptInterface):
 	names = ('c', 'javac')
 
 	def __call__(self, args):
-		print find_exec('javac')
+		print find_exec('javac', JAVA_HOME)
 
 
 class Jar (jc_iface.OptInterface):
@@ -230,7 +234,7 @@ class Jar (jc_iface.OptInterface):
 	names = ('j', 'jar') 
 
 	def __call__(self, args):
-		print find_exec('jar')
+		print find_exec('jar', JAVA_HOME)
    
 
 class JDKHome (jc_iface.OptInterface):
@@ -246,7 +250,12 @@ class JDKHome (jc_iface.OptInterface):
 
 	def __call__(self, args):
 
-		jdkh = get_jvm_env_var('JDK_HOME')
+        # So, we'll shortcut this a little...
+        # With new Java system, we didn't want JDK_HOME in the environment.
+        # This is ok though, since we only allow JDKs to be visible to
+        # java-config-1, so we can just return the value of JAVA_HOME :)
+		#jdkh = get_jvm_env_var('JDK_HOME')
+		jdkh = get_jvm_env_var('JAVA_HOME')
 
 		if jdkh is None: 
 			print
@@ -267,7 +276,12 @@ class JREHome (jc_iface.OptInterface):
 
 	def __call__(self, args):
 
-		jreh = get_jvm_env_var('JRE_HOME')
+        # So, we'll shortcut this a little...
+        # With new Java system, we didn't want JRE_HOME in the environment.
+        # This is ok though, since we only allow JDKs to be visible to
+        # java-config-1, so we can just return the value of JAVA_HOME :)
+		#jreh = get_jvm_env_var('JRE_HOME')
+		jreh = get_jvm_env_var('JAVA_HOME')
 
 		if jreh is None: 
 			print
@@ -304,7 +318,7 @@ class JavaVersion (jc_iface.OptInterface):
 	def __call__(self, args):
 
 		from commands import getoutput
-		print getoutput('%s -version' % find_exec('java'))
+		print getoutput('%s -version' % find_exec('java', JAVA_HOME))
 
 
 class Classpath (jc_iface.OptInterface):
@@ -330,7 +344,32 @@ class Classpath (jc_iface.OptInterface):
 			print ':'.join(cp)
 		else:			
 			#print bold('Entries in the classpath: \n')
-			print env['CLASSPATH']
+			try:
+				print env['CLASSPATH']
+			except KeyError:
+				# there is no CLASSPATH env set
+				print
+
+class Librarypath (jc_iface.OptInterface):
+
+	usage = (
+	  'Print entries in the package library.',
+
+	  'Print the library path for a package '
+	  'with --library=pkg1,pkg2 .'
+	)
+
+	names = ('i:', 'library=')
+
+	def __call__(self, args):
+		cp = []
+		for arg in args.split(','): 
+			try:
+				cp.append(collect_library(arg))
+			except OptionRuntimeError, err_msg:
+				warn(str(err_msg))
+		print ':'.join(cp)
+
 
 class Exec (jc_iface.OptInterface):
 
@@ -347,7 +386,7 @@ class Exec (jc_iface.OptInterface):
 	def __call__(self, args):
 
 		#print args
-		os.system(find_exec(args))
+		os.system(find_exec(args, JAVA_HOME))
 
 class ListAvailablePackages (jc_iface.OptInterface):
 
@@ -502,20 +541,22 @@ def set_vm(vm_name, system=False):
 		sh_out = EnvFileOutput()
 		sh_mkr = BashEnvEntry(system=True)
 	else:
-		sh_out = EnvFileOutput(
-		    config_file='java', 
-		    config_path=os.path.join(env['HOME'], '.gentoo')
-		)
-		sh_mkr = BashEnvEntry(system=False)
-
-		csh_out = EnvFileOutput(
-		    config_file='java.csh', 
-		    config_path=os.path.join(env['HOME'], '.gentoo')
-		)
-
-		csh_mkr = TcshEnvEntry(system=False)
-		csh_mkr.installOutputHandler(csh_out)
-		genv.installMaker(csh_mkr)
+		sys.stderr.write(red('Setting User VM with java-config-1 is no longer supported. Use java-config-2 instead\n'))
+		sys.exit(1)
+#		sh_out = EnvFileOutput(
+#		    config_file='java', 
+#		    config_path=os.path.join(env['HOME'], '.gentoo')
+#		)
+#		sh_mkr = BashEnvEntry(system=False)
+#
+#		csh_out = EnvFileOutput(
+#		    config_file='java.csh', 
+#		    config_path=os.path.join(env['HOME'], '.gentoo')
+#		)
+#
+#		csh_mkr = TcshEnvEntry(system=False)
+#		csh_mkr.installOutputHandler(csh_out)
+#		genv.installMaker(csh_mkr)
 
 	sh_mkr.installOutputHandler(sh_out)
 	genv.installMaker(sh_mkr)
@@ -523,12 +564,33 @@ def set_vm(vm_name, system=False):
 	genv.makeEnvEntry()
 
 	if systemVM: 
-		print 'System Virtual Machine set'
-		may_want_to_source()
+		print 'System Virtual Machine updated'
+		#may_want_to_source()
 	else: 
-		print 'Config options added to %s/.gentoo directory' % (env['HOME'],)
+		report_env_update()
 				
 
+class PrintVMEnvVar (jc_iface.OptInterface):
+
+	usage = (
+	'Print an environment variable from the currently selected VM',
+
+	'Outputs a specific environment variable for the specified VM'
+	)
+
+	names = ('g:', 'get-env=')
+	
+	single_arg = True
+
+	def __call__(self, args):
+		
+		env = get_jvm_env_var(args)
+		if env is None: 
+			print	
+		else:
+			print env
+
+
 class PrintVM (jc_iface.OptInterface):
 
 
@@ -609,32 +671,34 @@ class SetUserVM (jc_iface.OptInterface):
 	single_arg = True
 
 	def __call__(self, args):
+		sys.stderr.write(red('Setting the user vm with java-config-1 is longer supported by java-config-1. Use java-config-2 instead\n'))
+		sys.exit(1)
 
-		jc_dir = env['HOME'] + '/.gentoo'
-
-		if os.getuid() == 0: 
-			raise OptionRuntimeError, 'root should always use the system vm'
-
-		can_write = os.access(os.path.split(jc_dir)[0], os.R_OK|os.W_OK|os.X_OK)
-		if not can_write:
-			raise OptionRuntimeError('Cannot write to ${HOME}')
-
-		if not os.path.isdir(jc_dir):
-			os.mkdir(jc_dir)
-		elif not os.path.exists(jc_dir):
-			raise OptionRuntimeError('${HOME}/.gentoo exists but is not a directory')
-
-		set_vm(args)
-
-		if not os.path.isfile(jc_dir + '/java-env'): 
-			file(os.path.join(jc_dir, 'java-env'), 'w').write(
-			  source_java_classpath
-			)
-
-		if not os.path.isfile(jc_dir + '/java-env.csh'): 
-			file(os.path.join(jc_dir, 'java-env.csh'), 'w').write(
-			  source_java_classpath_csh
-			)
+#		jc_dir = env['HOME'] + '/.gentoo'
+#
+#		if os.getuid() == 0: 
+#			raise OptionRuntimeError, 'root should always use the system vm'
+#
+#		can_write = os.access(os.path.split(jc_dir)[0], os.R_OK|os.W_OK|os.X_OK)
+#		if not can_write:
+#			raise OptionRuntimeError('Cannot write to ${HOME}')
+#
+#		if not os.path.isdir(jc_dir):
+#			os.mkdir(jc_dir)
+#		elif not os.path.exists(jc_dir):
+#			raise OptionRuntimeError('${HOME}/.gentoo exists but is not a directory')
+#
+#		set_vm(args)
+#
+#		if not os.path.isfile(jc_dir + '/java-env'): 
+#			file(os.path.join(jc_dir, 'java-env'), 'w').write(
+#			  source_java_classpath
+#			)
+#
+#		if not os.path.isfile(jc_dir + '/java-env.csh'): 
+#			file(os.path.join(jc_dir, 'java-env.csh'), 'w').write(
+#			  source_java_classpath_csh
+#			)
 
 
 class SetSystemClasspath (jc_iface.OptInterface):
@@ -669,7 +733,7 @@ class SetSystemClasspath (jc_iface.OptInterface):
 				)
 
 			try:
-				fp.write('CLASSPATH=%s\n' % (collect_packages(args),))
+				fp.write('CLASSPATH=%s\n' % (norm_cp(collect_packages(args)),))
 			except (OSError, IOError), e:
 				raise OptionRuntimeError(
 				  'Error writing configuration file, ' + str(e)
@@ -697,42 +761,48 @@ class AddSystemClasspath (jc_iface.OptInterface):
 	conf_file = os.path.join('/', 'etc', 'env.d', '21java-classpath')
 
 	def __call__(self, args):
+		sys.stderr.write(red('Classpath operations are no longer supported by java-config-1. Use java-config-2 instead\n'))
+		sys.exit(1)
 
-		if args == '':
-			raise OptionRuntimeError(
-				'if you want to clean the classpath use --clean-system-classpath')
-
-		else:
-			old_classpath = None 
-
-			try:
-				old_classpath = file(self.conf_file, 'r').read().strip()
-
-			except (OSError, IOError), e:
-				warn ("Error reading classpath file " + str(e))
-				return
-
-			try:
-				old_classpath = old_classpath.split('=', 1)[1]
-				#old_classpath = re.sub('CLASSPATH=', '', old_classpath)
-
-			except IndexError:
-				warn ("Malformed CLASSPATH")
-				return
-
-			try:
-				file(self.conf_file, 'w').write(
-			  		'CLASSPATH=%s%s\n' % (
-			    		old_classpath is not None and (old_classpath + ':') or '',
-			    		collect_packages(args),))
-
-			except (OSError, IOError), e:
-				warn ("Error writing classpath file " + str(e))
-				return
-
-
-			print 'System classpath set'
-			may_want_to_source() 
+#		if args == '':
+#			raise OptionRuntimeError(
+#				'if you want to clean the classpath use --clean-system-classpath')
+#
+#		else:
+#			old_classpath = None 
+#
+#			if os.path.exists(self.conf_file):
+#				try:
+#					old_classpath = file(self.conf_file, 'r').read().strip()
+#
+#				except (OSError, IOError), e:
+#					warn ("Error when reading classpath file " + str(e))
+#					return
+#
+#				try:
+#					old_classpath = old_classpath.split('=', 1)[1]
+#					#old_classpath = re.sub('CLASSPATH=', '', old_classpath)
+#		
+#				except IndexError:
+#					warn ("Malformed CLASSPATH in /etc/env.d/21java-classpath")
+#					return
+#			else:
+#				old_classpath = ""
+#
+#
+#			try:
+#				
+#				file(self.conf_file, 'w').write(
+#			  		'CLASSPATH=%s\n' % (
+#			    		norm_cp(old_classpath + ':' + collect_packages(args)),))
+#
+#			except (OSError, IOError), e:
+#				warn ("Error writing classpath file " + str(e))
+#				return
+#
+#
+#			print 'System classpath set'
+#			may_want_to_source() 
 
 class SetUserClasspath (jc_iface.OptInterface):
 
@@ -747,21 +817,26 @@ class SetUserClasspath (jc_iface.OptInterface):
 	names = ('a:', 'set-user-classpath=')
 
 	def __call__(self, args):
+		sys.stderr.write(red('Classpath operations are no longer supported by java-config-1. Use java-config-2 instead\n'))
+		sys.exit(1)
 
-		jc_dir = os.path.join(env['HOME'], '.gentoo')
+#		jc_dir = os.path.join(env['HOME'], '.gentoo')
+#
+#		if not os.path.isdir(jc_dir):
+#			os.mkdir(jc_dir)
+#
+#		file(os.path.join(jc_dir, 'java-env-classpath'), 'w').write(
+#		  'CLASSPATH=${CLASSPATH}:' + collect_packages(args)
+#		)
+#
+#		if not os.path.isfile(os.path.join(jc_dir, 'java-env')): 
+#
+#			file(os.path.join(jc_dir, 'java-env'), 'w').write(
+#				source_java_classpath
+#			)
+#		
+#			report_env_update()
 
-		if not os.path.isdir(jc_dir):
-			os.mkdir(jc_dir)
-
-		file(os.path.join(jc_dir, 'java-env-classpath'), 'w').write(
-		  'CLASSPATH=${CLASSPATH}:' + collect_packages(args)
-		)
-
-		if not os.path.isfile(os.path.join(jc_dir, 'java-env')): 
-
-			file(os.path.join(jc_dir, 'java-env'), 'w').write(
-				source_java_classpath
-			)
 
 class AppendUserClasspath (jc_iface.OptInterface):
 
@@ -776,24 +851,28 @@ class AppendUserClasspath (jc_iface.OptInterface):
 	names = ('b:', 'add-user-classpath=')
 
 	def __call__(self, args):
+		sys.stderr.write(red('Classpath operations are no longer supported by java-config-1. Use java-config-2 instead\n'))
+		sys.exit(1)
 
-		jc_dir = os.path.join(env['HOME'], '.gentoo')
-		old_classpath = '' 
-
-		if not os.path.isdir(jc_dir):
-			os.mkdir(jc_dir)
-
-		elif os.path.isfile(os.path.join(jc_dir, 'java-env-classpath')):
-			old_classpath = file(os.path.join(jc_dir, 'java-env-classpath'), 'r').read()
-			old_classpath = re.sub('CLASSPATH=\${CLASSPATH}:', '', old_classpath)[:-1]
-
-		file(os.path.join(jc_dir, 'java-env-classpath'), 'w').write(
-		  'CLASSPATH=${CLASSPATH}:' + old_classpath + ':' + collect_packages(args)
-		)
-
-		if not os.path.isfile(os.path.join(jc_dir, 'java-env')): 
-			file(os.path.join(jc_dir, 'java-env'), 'w').write(source_java_classpath)
-
+#		jc_dir = os.path.join(env['HOME'], '.gentoo')
+#		old_classpath = '' 
+#
+#		if not os.path.isdir(jc_dir):
+#			os.mkdir(jc_dir)
+#
+#		elif os.path.isfile(os.path.join(jc_dir, 'java-env-classpath')):
+#			old_classpath = file(os.path.join(jc_dir, 'java-env-classpath'), 'r').read()
+#			old_classpath = re.sub('CLASSPATH=\${CLASSPATH}:', '', old_classpath)
+#
+#		file(os.path.join(jc_dir, 'java-env-classpath'), 'w').write(
+#		  'CLASSPATH=${CLASSPATH}:' + norm_cp(old_classpath + ':' + collect_packages(args))
+#		)
+#
+#		if not os.path.isfile(os.path.join(jc_dir, 'java-env')): 
+#			file(os.path.join(jc_dir, 'java-env'), 'w').write(source_java_classpath)
+#
+#		report_env_update()
+		
 class CleanSystemClasspath (jc_iface.OptInterface):
 
 	usage = (
@@ -809,15 +888,17 @@ class CleanSystemClasspath (jc_iface.OptInterface):
 	env_file = '/etc/env.d/21java-classpath'
 
 	def __call__(self, args):
+		sys.stderr.write(red('Classpath operations are no longer supported by java-config-1. Use java-config-2 instead\n'))
+		sys.exit(1)
 
 		#if os.getuid() != 0: raise OptionRuntimeError, 'root access required'
-		if os.path.isfile(self.env_file):
-			print 'Cleaning system classpath...'
-			os.remove(self.env_file)
-			#if os.system('/usr/sbin/env-update') != 0:
-			#	raise OptionRuntimeError, 'env-update command not found!'
-			print 'System classpath cleaned'
-			may_want_to_source()
+#		if os.path.isfile(self.env_file):
+#			print 'Cleaning system classpath...'
+#			os.remove(self.env_file)
+#			#if os.system('/usr/sbin/env-update') != 0:
+#			#	raise OptionRuntimeError, 'env-update command not found!'
+#			print 'System classpath cleaned'
+#			may_want_to_source()
 
 class CleanUserClasspath (jc_iface.OptInterface):
 
@@ -831,17 +912,25 @@ class CleanUserClasspath (jc_iface.OptInterface):
 
 	names = ('x', 'clean-user-classpath')
 	require_root = False
-	env_file = os.path.join(env['HOME'], '.gentoo', 'java-env-classpath')
+
+	def __init__ (self):
+
+		self.env_file = os.path.join(env['HOME'], '.gentoo', 'java-env-classpath')
 
 	def __call__(self, args):
+		sys.stderr.write(red('Classpath operations are no longer supported by java-config-1. Use java-config-2 instead\n'))
+		sys.exit(1)
 
-		if os.path.isfile(self.env_file):
-			print 'Cleaning user classpath...'
-			os.remove(self.env_file)
-			print 'User classpath cleaned' 
-		else:
-			print 'No user classpath file found'
+#		if os.path.isfile(self.env_file):
+#			print 'Cleaning user classpath...'
+#			os.remove(self.env_file)
+#			print 'User classpath cleaned' 
+#			report_env_update()
+#		else:
+#			print 'No user classpath file found'
 
+
+		
 class NoColors (jc_iface.OptInterface):
 
 	usage = (
